pilot.api.data.api

Package pilot :: Package api :: Package data :: Module api |

# Module api

source code

This file contains the API for the PilotData Framework.

Classes
| PilotDataDescription PilotDataDescription (PDD).
| PilotData PilotData (PD).
| PilotDataService PilotDataService (PDS).
| DataUnitService DataUnitService (DUS).
| DataUnitDescription DataUnitDescription (DUD).
| DataUnit DataUnit (DU).

Variables
| __package__ = `None` hash(x)